/**
 * https://www.tailwind-kit.com/components/footer
 */
import { Link } from "gatsby";

import React from "react";
import { graphql, useStaticQuery } from "gatsby";
import { StaticImage } from "gatsby-plugin-image";

import logo from "../images/logo-egeo.png";

// // Partenaires logos
// import regionLogo from "../images/region-rbfc-logo.jpg"
// import drealLogo from "../images/dreal-bfc-logo.png"
// import ofbLogo from "../images/ofb-logo.jpg"
// import arbLogo from "../images/arb-logo.jpg"

interface Props {}

const Footer = (props: Props) => {
  const data = useStaticQuery(
    graphql`
      query {
        site {
          buildTime
        }
        api {
          pages(
            where: {
              page_categories: { category: { name: { _eq: "footer" } } }
            }
            order_by: { position: asc }
          ) {
            id
            author
            image_url
            created_at
            updated_at
            title
            published
            position
            toc
          }
        }
      }
    `
  );
  const pages = { ...data.api.pages };
  //     < className="text-sm font-semibold text-gray-400 tracking-wider uppercase">

  const pageItems = Object.keys(pages).map(function (index) {
    return (
      <Link
        key={"footer_item_" + pages[index].id}
        to={
          "/" +
          pages[index].title
            .toLowerCase()
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "")
        }
        className="text-base text-gray-500 hover:text-gray-900"
      >
        {pages[index].title}
      </Link>
    );
  });

  return (
    <footer
      className="bg-white border-t border-gray-200 w-full mt-12"
      aria-labelledby="footer-heading"
    >
      <div className="max-w-7xl mx-auto py-8 px-4 sm:px-6 lg:px-8">
        <div className="xl:grid xl:grid-cols-3 xl:gap-8">
          <div className="space-y-8 xl:col-span-1">
            <Link to="/" aria-label="Back to homepage" className="">
              <img src={logo} alt="logo" className="block h-12 w-auto" />
            </Link>
          </div>
          <div className="mt-4 col-span-2 grid grid-cols-1 gap-10 sm:grid-cols-4 lg:grid-cols-4">
            {pageItems}
          </div>
        </div>
      </div>
      <div className="w-full text-center text-sm mt-10">By GEOFIT 2022</div>
    </footer>
  );
};

export default Footer;
